# TecJustica Admin

Painel de monitoramento

Email
Senha

Custo 30d

--

USD

Chamadas LLM

--

ultimos 30 dias

Tool Calls

--

ultimos 30 dias

Usuarios Ativos

--

ultimos 30 dias

## Custo diario por modelo (30 dias)

## Distribuicao de custo por modelo

## Frequencia de uso por tool (30 dias)

## Ultimas 50 chamadas LLM

Data/Hora | Usuario | Tool | Modelo | Tokens | Custo (USD) | Duracao
--- | --- | --- | --- | --- | --- | ---
Carregando...